#
#
#-----------------------------------------------------------------------------
#
# COMPONENT_NAME: examples
#
# ABSTRACT: makefile to generate the example LDAP client programs
#
# ORIGINS: 202,27
#
# (C) COPYRIGHT International Business Machines Corp. 1997, 1998, 2001,2002
# All Rights Reserved
# Licensed Materials - Property of IBM
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#-----------------------------------------------------------------------------
# Copyright (c) 1994 Regents of the University of Michigan.
# All rights reserved.
#
# Redistribution and use in source and binary forms are permitted
# provided that this notice is preserved and that due credit is given
# to the University of Michigan at Ann Arbor. The name of the University
# may not be used to endorse or promote products derived from this
# software without specific prior written permission. This software
# is provided ``as is'' without express or implied warranty.
#-----------------------------------------------------------------------------
#
# This makefile will build the example programs whose source is contained
# in this directory.  The four programs generated are:
#  ldapsearch
#  ldapmodify
#  ldapadd (a hard-link to ldapmodify)
#  ldapmodrdn
#  ldapdelete
#  ldapchangepwd
#  ldapexop
# In addition to being examples of the use of the LDAP client api, these
# programs are useful command line utilities.  See the README file for
# more details.

#
# default definitions for Unix utilities (may be changed here)
CC	= gcc
RM	= rm -f
HARDLN	= ln
MKDIR	= mkdir -p

# This variable indicates the architecture on which the binaries are desired

 BITS	= 32

#############################################################################
## General compiler options                                                ##
#############################################################################

DEFINES	= -DLINUX -D_GCC3
# Note: replace ../include with the appropriate path to the LDAP header files.
INCLUDES= -I/opt/ibm/ldap/V6.0/include -I../include
CFLAGS	= $(INCLUDES) $(DEFINES)

#############################################################################
## Options for building 32-bit targets on ppc linux						   ##
#############################################################################
#
#--------------------------------------------------------------------
# Use the following definition to link the sample programs with
# the shared LDAP library dynamically.  
  CLIENT_LIBS = -lidsldif -libmldap 
  LIBS = -L/opt/ibm/ldap/V6.0/lib -L/usr/lib -lpthread -ldl
#--------------------------------------------------------------------
#
# Or use this definition to link the LDAP library statically:
#  CLIENT_LIBS = -lidsldifstatic -libmldapstatic 
#  LIBS	=  -L/opt/ibm/ldap/V6.0/lib -L../lib -L/usr/lib -lpthread -ldl
#--------------------------------------------------------------------

  LFLAGS  = -Wl,-rpath,/opt/ibm/ldap/V6.0/lib $(LIBS) $(CLIENT_LIBS)
#
#############################################################################
## Options for building 64-bit targets on ppc linux
#############################################################################
#------------------------------------------------------------------
# Use the following definition to link the sample programs with
# the shared LDAP library dynamically.
# CLIENT_LIBS = -lidsldif -libmldapdbg -libmldap
# LIBS  = -L/opt/ibm/ldap/V6.0/lib64 -L/lib64 -lpthread -ldl
#------------------------------------------------------------------
# Or use this definition to link the LDAP library statically:
# CLIENT_LIBS = -libmldapstatic -lidsldifstatic
# LIBS  = -L/opt/ibm/ldap/V6.0/lib64 -L../lib64 -L/lib64 -lpthread -ldl
#------------------------------------------------------------------
# LFLAGS  = -Wl,-rpath,/opt/ibm/ldap/V6.0/lib64 $(LIBS) $(CLIENT_LIBS)
#############################################################################
## Targets                                                                 ##
#############################################################################

all:	ldapsearch ldapmodify ldapdelete ldapmodrdn ldapadd ldapchangepwd ldapexop

ldapsearch:	
	$(MKDIR) $(BITS)
	$(CC) $(CFLAGS) -o $(BITS)/$@ ldapsearch.c $(LFLAGS)

ldapmodify:
	$(MKDIR) $(BITS)
	$(CC) $(CFLAGS) -o $(BITS)/$@ ldapmodify.c $(LFLAGS)

ldapdelete:
	$(MKDIR) $(BITS)
	$(CC) $(CFLAGS) -o $(BITS)/$@ ldapdelete.c $(LFLAGS)

ldapmodrdn:
	$(MKDIR) $(BITS)
	$(CC) $(CFLAGS) -o $(BITS)/$@ ldapmodrdn.c $(LFLAGS)

ldapchangepwd:
	$(MKDIR) $(BITS)
	$(CC) $(CFLAGS) -o $(BITS)/$@ ldapchangepwd.c $(LFLAGS)

ldapexop:
	$(MKDIR) $(BITS)
	$(CC) $(CFLAGS) -o $(BITS)/$@ ldapexop.c $(LFLAGS)

ldapadd:	ldapmodify
	$(RM) $(BITS)/$@
	$(HARDLN) $(BITS)/ldapmodify $(BITS)/ldapadd

clean:	
	$(RM) *.o core a.out $(BITS)/*.o $(BITS)/core $(BITS)/a.out $(BITS)/ldapsearch $(BITS)/ldapmodify $(BITS)/ldapdelete \
		$(BITS)/ldapmodrdn $(BITS)/ldapadd $(BITS)/ldapchangepwd $(BITS)/ldapexop

